@@ -1,12 +1,17 @@
 #ifndef COMMON_H
 #define COMMON_H
 
-#define FASTP_VER "0.20.1"
+#define FASTP_VER "0.23.2"
 
 #define _DEBUG false
 
-typedef long int64;
-typedef unsigned long uint64;
+#ifndef _WIN32
+	typedef long int64;
+	typedef unsigned long uint64;
+#else
+	typedef long long int64;
+	typedef unsigned long long uint64;
+#endif
 
 typedef int int32;
 typedef unsigned int uint32;
@@ -65,5 +70,4 @@ const static char* FAILED_TYPES[FILTER_RESULT_TYPES] = {
 	"", "", "", ""
 };
 
-
 #endif /* COMMON_H */
