@@ -37,6 +37,7 @@ int main(int argc, char* argv[]){
     cmd.add<string>("out2", 'O', "read2 output file name", false, "");
     cmd.add<string>("unpaired1", 0, "for PE input, if read1 passed QC but read2 not, it will be written to unpaired1. Default is to discard it.", false, "");
     cmd.add<string>("unpaired2", 0, "for PE input, if read2 passed QC but read1 not, it will be written to unpaired2. If --unpaired2 is same as --unpaired1 (default mode), both unpaired reads will be written to this same file.", false, "");
+    cmd.add<string>("overlapped_out", 0, "for each read pair, output the overlapped region if it has no any mismatched base.", false, "");
     cmd.add<string>("failed_out", 0, "specify the file to store reads that cannot pass the filters.", false, "");
     cmd.add("merge", 'm', "for paired-end input, merge each pair of reads into a single read if they are overlapped. The merged reads will be written to the file given by --merged_out, the unmerged reads will be written to the files specified by --out1 and --out2. The merging mode is disabled by default.");
     cmd.add<string>("merged_out", 0, "in the merging mode, specify the file name to store merged output, or specify --stdout to stream the merged output", false, "");
@@ -66,6 +67,11 @@ int main(int argc, char* argv[]){
     cmd.add<int>("trim_tail2", 'T', "trimming how many bases in tail for read2. If it's not specified, it will follow read1's settings", false, 0);
     cmd.add<int>("max_len2", 'B', "if read2 is longer than max_len2, then trim read2 at its tail to make it as long as max_len2. Default 0 means no limitation. If it's not specified, it will follow read1's settings", false, 0);
 
+    // duplication evaluation and deduplication
+    cmd.add("dedup", 'D', "enable deduplication to drop the duplicated reads/pairs");
+    cmd.add<int>("dup_calc_accuracy", 0, "accuracy level to calculate duplication (1~6), higher level uses more memory (1G, 2G, 4G, 8G, 16G, 24G). Default 1 for no-dedup mode, and 3 for dedup mode.", false);
+    cmd.add("dont_eval_duplication", 0, "don't evaluate duplication rate to save time and use less memory.");
+
     // polyG tail trimming
     cmd.add("trim_poly_g", 'g', "force polyG tail trimming, by default trimming is automatically enabled for Illumina NextSeq/NovaSeq data");
     cmd.add<int>("poly_g_min_len", 0, "the minimum length to detect polyG in the read tail. 10 by default.", false, 10);
@@ -133,7 +139,7 @@ int main(int argc, char* argv[]){
     cmd.add<string>("report_title", 'R', "should be quoted with \' or \", default is \"fastp report\"", false, "fastp report");
 
     // threading
-    cmd.add<int>("thread", 'w', "worker thread number, default is 2", false, 2);
+    cmd.add<int>("thread", 'w', "worker thread number, default is 3", false, 3);
 
     // split the output
     cmd.add<int>("split", 's', "split output by limiting total split file number with this option (2~999), a sequential number prefix will be added to output name ( 0001.out.fq, 0002.out.fq...), disabled by default", false, 0);
@@ -167,6 +173,7 @@ int main(int argc, char* argv[]){
     opt.unpaired1 = cmd.get<string>("unpaired1");
     opt.unpaired2 = cmd.get<string>("unpaired2");
     opt.failedOut = cmd.get<string>("failed_out");
+    opt.overlappedOut = cmd.get<string>("overlapped_out");
     // write to the same file
     if(opt.unpaired2.empty())
         opt.unpaired2 = opt.unpaired1;
@@ -180,6 +187,18 @@ int main(int argc, char* argv[]){
     opt.verbose = cmd.exist("verbose");
     opt.fixMGI = cmd.exist("fix_mgi_id");
 
+    // duplication evaluation and deduplication
+    opt.duplicate.dedup = cmd.exist("dedup");
+    opt.duplicate.enabled = !cmd.exist("dont_eval_duplication") || cmd.exist("dedup") ;
+    if(!cmd.exist("dup_calc_accuracy")) {
+        if(opt.duplicate.dedup)
+            opt.duplicate.accuracyLevel = 3;
+        else
+            opt.duplicate.accuracyLevel = 1;
+    } else {
+        opt.duplicate.accuracyLevel = min(6, max(1, cmd.get<int>("dup_calc_accuracy")));
+    }
+
     // merge PE
     opt.merge.enabled = cmd.exist("merge");
     opt.merge.out = cmd.get<string>("merged_out");
