@@ -11,8 +11,8 @@ Options::Options(){
     out1 = "";
     out2 = "";
     reportTitle = "fastp report";
-    thread = 1;
-    compression = 2;
+    thread = 3;
+    compression = 4;
     phred64 = false;
     dontOverwrite = false;
     inputFromSTDIN = false;
@@ -27,6 +27,7 @@ Options::Options(){
     seqLen1 = 151;
     seqLen2 = 151;
     fixMGI = false;
+    writerBufferSize = 0x01L<<22; // 4M writer buffer for per output by default
 }
 
 void Options::init() {
@@ -196,6 +197,12 @@ bool Options::validate() {
             error_exit(out2 + " already exists and you have set to not rewrite output files by --dont_overwrite");
         }
     }
+    if(!overlappedOut.empty()) {
+        //check_file_writable(out2);
+        if(dontOverwrite && file_exists(overlappedOut)) {
+            error_exit(overlappedOut + " already exists and you have set to not rewrite output files by --dont_overwrite");
+        }
+    }
     if(!isPaired()) {
         if(!unpaired1.empty()) {
             cerr << "Not paired-end mode. Ignoring argument --unpaired1 = " << unpaired1 << endl;
@@ -205,6 +212,10 @@ bool Options::validate() {
             cerr << "Not paired-end mode. Ignoring argument --unpaired2 = " << unpaired2 << endl;
             unpaired2 = "";
         }
+        if(!overlappedOut.empty()) {
+            cerr << "Not paired-end mode. Ignoring argument --overlapped_out = " << overlappedOut << endl;
+            overlappedOut = "";
+        }
     }
     if(split.enabled) {
         if(!unpaired1.empty()) {
