@@ -33,13 +33,15 @@ class DuplicationOptions {
 public:
     DuplicationOptions() {
         enabled = true;
-        keylen = 12;
         histSize = 32;
+        dedup = false;
+        accuracyLevel = 1;
     }
 public:
     bool enabled;
-    int keylen;
     int histSize;
+    bool dedup;
+    int accuracyLevel;
 };
 
 class IndexFilterOptions {
@@ -306,6 +308,8 @@ public:
     // file name of failed reads output
     string failedOut;
     // json file
+    string overlappedOut;
+    // json file
     string jsonFile;
     // html file
     string htmlFile;
@@ -371,6 +375,8 @@ public:
     bool verbose;
     // merge options
     MergeOptions merge;
+    // the buffer size for writer
+    size_t writerBufferSize;
 
 };
 
